# Chatto

A unified API wrapper for YouTube and Twitch chat bots.

## Contributing

Chatto is open to contributions. To find out where to get started, have a look at the [contributing guide](https://github.com/parafoxia/chatto/blob/main/CONTRIBUTING.md).

## License

The Chatto module for Python is licensed under the [BSD 3-Clause License](https://github.com/parafoxia/chatto/blob/main/LICENSE).
